//
//  OrderListModel.swift
//  GeliBusinessPlatform
//
//  Created by 刘俊宏 on 2020/5/12.
//  Copyright © 2020 junye lu. All rights reserved.
//

import Foundation
import ObjectMapper
//订单列表
class OrderListModel: Mappable {
    var code:Int?
    var message : String?
    var data : Array<OrderListDataModel>?
    
    required init?( map: Map) {
        
    }
    func mapping(map: Map) {
        code <- map["code"]
        message <- map["message"]
        data <- map["data"]
    }
}

class OrderListDataModel: Mappable {
    var order_id : Int? //订单id
    var order_sn : String? //订单SN
    var add_time : Double? //下单时间
    var sum_amount : String? //订单价格
    var order_status : Int? //订单状态
    var order_status_d : Int? //订单详细状态
    var goods_before_pay :Int? //是否为先货后款：0否 1是
    var order_type : Int? //订单类型 1普通2期货3团购4预售
    var pay_status : Int? //支付状态
    var pay_type : Int? //支付类型
    var apply_cancel:Int?  //申请取消订单标识：0待申请 1申请取消中 2已取消
    var shipping_status : Int? //发货状态
    var from : Int? //订单来源，0PC商城，1android商城，2IOS商城，3后台(销售)下单，4小程序段
    var user_name : String? //购买用户
    var cus_name : String? //购买客户
    var goods_number : String? //订单商量总数
    var order_goods : Array<OrderListGoodsModel>?

    required init?( map: Map) {
    }
    
    func mapping(map: Map) {
        order_id <- map["order_id"]
        order_sn <- map["order_sn"]
        add_time <- map["add_time"]
        sum_amount <- map["sum_amount"]
        goods_before_pay <- map["goods_before_pay"]
        order_status <- map["order_status"]
        order_status_d <- map["order_status_d"]
        order_type <- map["order_type"]
        pay_status <- map["pay_status"]
        pay_type <- map["pay_type"]
        shipping_status <- map["shipping_status"]
        apply_cancel <- map["apply_cancel"]
        from <- map["from"]
        user_name <- map["user_name"]
        cus_name <- map["cus_name"]
        goods_number <- map["goods_number"]
        order_goods <- map["order_goods"]

    }
    
}
class OrderListGoodsModel: Mappable {
    var goods_number:Int?
    var goods_name : String?
 
    required init?( map: Map) {
        
    }
    func mapping(map: Map) {
        goods_number <- map["goods_number"]
        goods_name <- map["goods_name"]
    }
}
//MARK:--根据order_type返回字符串状态
func orderTypeStrByInt(statusNumber:Int) -> String? {
    var str = ""
    
    switch statusNumber {
    case 1:
        str = "普通"
        break
    case 2:
        str = "期货"
        break
    case 3:
        str = "团购"
        break
    case 4:
        str = "预售"
        break
    default: break
        
    }
    return str
}
//MARK:--根据order_status_d返回字符串状态
func orderStatusStrByIntAndBtn(leftBtn:UIButton,rightBtn:UIButton,statusNumber:Int) -> String? {
    var str = ""
    leftBtn.isHidden = true
    rightBtn.setTitle("查看详情", for: .normal)
    rightBtn.backgroundColor = UIColor.white
    rightBtn.layer.borderWidth =  1
    rightBtn.layer.borderColor = UIColor.init(named: "按钮背景颜色")?.cgColor
    rightBtn.setTitleColor(UIColor.init(named: "按钮背景颜色"), for: .normal)

    switch statusNumber {
    case 0:
        str = "待接单"
        leftBtn.isHidden = false
        rightBtn.setTitle("确认订单", for: .normal)
        rightBtn.setTitleColor(UIColor.white, for: .normal)
        rightBtn.backgroundColor = UIColor.init(named: "按钮背景颜色")
        rightBtn.layer.borderColor = UIColor.init(named: "按钮背景颜色")?.cgColor
        break
    //待付款
    case 1:
        str = "待付款"
        
        rightBtn.setTitle("取消订单", for: .normal)
        rightBtn.setTitleColor(UIColor.init(named: "灰色字体颜色"), for: .normal)
        rightBtn.backgroundColor = UIColor.white
        rightBtn.layer.borderColor = UIColor.init(named: "灰色字体颜色")?.cgColor
        break
    case 6:
        str = "待发货"
        break
    case 7:
        str = "待收货"
        break
    //订单完成
    case 5:
        str = "订单完成"
        break
    //订单关闭
    case 8:
        str = "订单关闭"
        break
    //已取消
    case 2:
        str = "已取消" //用户取消（预售
        break
    default:
        break
        
    }
    return str
}
 
//MARK:--根据order_status_d返回字符串状态
func orderStatusDstrByInt(statusNumber:Int) -> String? {
    var str = ""
    
    switch statusNumber {
    case 1:
        str = "待接单"
        break
        
    //待付款
    case 11:
        str = "已确定"
        break
    case 12:
        str = "已付定金"
        break
        
    case 61:
        str = "待发货"
        break
    case 71:
        str = "待收货"
        break
        
    //订单完成
    case 51:
        str = "仅退款"
        break
    case 52:
        str = "仅退货"
        break
    case 53:
        str = "订单完成"
        break
        
    //订单关闭
    case 81:
        str = "退货退款"
        break
        
    //已取消
    case 21:
        str = "待付款" //用户取消（预售
        break
    case 22:
        str = "待确认" //用户取消（预售
        break
    case 23:
        str = "未付定金" //系统取消（预售
        break
    case 24:
        str = "未付尾款" // 系统取消（预售
        break
    case 25:
        str = "待确认" // 商家取消（预售
        break
    case 26:
        str = "已确认" // 商家取消（预售
        break
    case 27:
        str = "已付定金" //商家取消（预售
        break
    case 28:
        str = "待付款" // 商家取消（普通
        break
    case 29:
        str = "待付款" //用户取消（普通
        break
    default: break
        
    }
    return str
}
