//
//  WarehouseInterface.swift
//  GeliBusinessPlatform
//
//  Created by junye lu on 2020/5/18.
//  Copyright © 2020 junye lu. All rights reserved.
//

import Foundation
import Alamofire
import SwiftyJSON
import ObjectMapper
//MARK: --商家仓库列表
/**
 params-key:
 
 user_token(验证token)
 keyword（关键字）
 page(第几页)
 
 */
func warehouseList(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) { NetworkRequest.sharedInstance.postRequest("商家仓库列表", params, { (rep:DataResponse<ShopWarehouseListModel>) in
}, success: { (data) in
    success(data)
}) { (error) in
    }
}

//MARK: -- 商家详情
/**
 params-key:
 user_token(验证token)
 w_id(仓库id)
 */
func WarehouseDetail(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商家仓库详情", params, { (rep:DataResponse<ShopWarehouseDetailModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MRAK: - 商家仓库添加
//params-key
/*
 user_token
 w_name  仓库名称
 w_type  仓库类型，1常温、2冷藏、3冷冻
 position_str  库位名，多库位用逗号拼接
 w_address  仓库地址
 volume  仓库容积
 area  仓库面积
 contact  联系人
 contact_number      联系电话
 mail 邮箱
 is_default  是否默认，1是0非
 */
func ShopWarehouseAdd(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商家仓库添加", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MRAK: - 商家仓库修改
//params-key
/*
 user_token
 w_name  仓库名称
 w_id 仓库id
 w_type  仓库类型，1常温、2冷藏、3冷冻
 position_str  库位名，多库位用逗号拼接
 w_address  仓库地址
 volume  仓库容积
 area  仓库面积
 contact  联系人
 contact_number      联系电话
 mail 邮箱
 is_default  是否默认，1是0非
 warehouse_position 仓库库位信息，必须要有一个库位json字符串，字段见下表
 */
func ShopWarehouseEdit(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商家仓库修改", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MRAK: - 商家仓库删除
//params-key
/*
 user_token
 w_id  仓库id，仓库中有库存则不可删除
 */
func ShopWarehouseDel(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商家仓库删除", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 获取入库的基本信息
/**
 params-key:
 user_token(验证token)
 goods_id(仓库id)
 */
func InputInitInfo(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("获取入库的基本信息", params, { (rep:DataResponse<InputInitInfoModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 获取出库的基本信息
/**
 params-key:
 user_token(验证token)
 p_id(库位id，直接出库时需要根据库位获取对应的商品数据)
 出库与入库内容一致。共用InputInitInfoModel 
 */
func OutputInitInfo(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("获取出库的基本信息", params, { (rep:DataResponse<InputInitInfoModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 商品入库审核
/**
 params-key:
 user_token(验证token)
 io_id(出/入库单号)
 goods_info(商品数据，json字符串，字段见下表)
 w_id（入库的仓库id    ）
 p_id（入库的库位id       ）
 iog_id（出/入库商品id        ）
 */
func GoodsInputAudit(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品入库审核", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}


//MARK: -- 商品入库
/**
 params-key:
 user_token(验证token)
 w_id    (仓库id)
 p_id(库位id    )
 i_type（入库类型 ）
 入库类型,1采购，2调入，3退货，4生产，5调出被拒绝，6外采，7其他，8固定采购，9临时采购
 
 apply_remark（入库备注        ）
 goods_info（入库商品信息，二维数组转json格式，字段见下表        ）
 goods_id 商品id
 sku_id 商品sku_id
 goods_name 商品名
 goods_spec 商品规格
 number 入库数量
 price 商品价格
 amount 采购价格
 production_data 生产日期，时间戳格式
 shelf_life 保质期，单位：天
 report_id 检测报告id，未选择填0
 pog_id 固定值：1
 */
func GoodsInput(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品入库", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 商品入库申请
/**
 params-key:
 user_token(验证token)
 w_id    (仓库id)
 p_id(库位id    )
 i_type（入库类型 ）
 入库类型,1采购，2调入，3退货，4生产，5调出被拒绝，6外采，7其他，8固定采购，9临时采购
 
 apply_remark（入库备注        ）
 
 goods_info（入库商品信息，二维数组转json格式，字段见下表        ）
 goods_id 商品id
 sku_id 商品sku_id
 goods_name 商品名
 goods_spec 商品规格
 number 入库数量
 price 商品价格
 amount 采购价格
 production_data 生产日期，时间戳格式
 shelf_life 保质期，单位：天
 report_id 检测报告id，未选择填0
 pog_id 固定值：1
 */
func GoodsInputApply(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品入库申请", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 添加检测报告

/**
 params-key:
 user_token(验证token)
 report_sn    (报告编码    )
 report_type 报告类型,1检验检测报告，2关检报告，3检验检疫合格证
goods_id
 sku_id
 file_url
 */
func GoodsReportAdd(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("添加检测报告", params, { (rep:DataResponse<GoodsReportAddModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 获取商品批次

/**
 params-key:
 user_token(验证token)
 sku_id    (商品sku_id     )
 p_id 库位id

 */
func GetGoodBatch(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("获取商品批次", params, { (rep:DataResponse<GetGoodBatchModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 商品出库

/**
 params-key:
 user_token(验证token)
 o_type    (出库类型，值见下文   )
 出库类型 值：
 1销售，2调出，3报损，4赠品，5自用，6生产使用，7过期处理，8用户试用，9采购退货，10其他
 audit_remark 出库备注
goods_info 入库商品,二维数组json字符串，字段见下表
 goods_id 商品id
 goods_name 商品名
 goods_spec 商品规格
 sku_id
 number 出库数量
 batch_info 批次信息,二维数组(此处不用转json),用户不填传没有key的空数组,后端根据算法自动分配批次，字段见下表
 [
 w_id 仓库id
 p_id 库位id
 number 批次数量
 production_data   生产日期
 shelf_life 保质期
 valid_date 过期时间
 batch_id 批次id
 report_id 商品报告id
 ]
 */
func GoodsOutput(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品出库", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 商品申请出库

/**
 params-key:
 user_token(验证token)
 o_type    (出库类型，值见下文   )
 出库类型 值：
 1销售，2调出，3报损，4赠品，5自用，6生产使用，7过期处理，8用户试用，9采购退货，10其他
 audit_remark 出库备注
goods_info 入库商品,二维数组json字符串，字段见下表
 goods_id 商品id
 goods_name 商品名
 goods_spec 商品规格
 sku_id
 number 出库数量
 
 */
func GoodsOutputApply(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品申请出库", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}


//MARK: -- 商品审核出库

/**
 params-key:
 user_token(验证token)
 io_id    (出/入库单id     )

 audit_remark 审核出库备注
goods_info 入库商品,二维数组json字符串，字段见下表
 goods_id 商品id
 goods_name 商品名
 goods_spec 商品规格
 sku_id
 number 出库数量
 batch_info 批次信息,二维数组(此处不用转json),用户不填传没有key的空数组,后端根据算法自动分配批次，字段见下表
 [
 w_id 仓库id
 p_id 库位id
 number 批次数量
 production_data   生产日期
 shelf_life 保质期
 valid_date 过期时间
 batch_id 批次id
 report_id 商品报告id
 ]
 */
func GoodsOutputAudit(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品审核出库", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 出入库记录

/**
 params-key:
 user_token(验证token)
 status    出入库(审核)状态，1审核中，2通过，3不通过；0全部
 page 页数
 
 */
func WarehouseIoList(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("出入库记录", params, { (rep:DataResponse<WarehouseIoListModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 查看出入库单详情(已审核)

/**
 params-key:
 user_token(验证token)
 io_id    出入库单id
 
 */
func IoGoodsDetail(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("查看出入库单详情(已审核)", params, { (rep:DataResponse<IoGoodsDetailModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 商品出库审核详情(未审核状态)

/**
 params-key:
 user_token(验证token)
 io_id    出入库单id
 
 */
func OutGoodsDetail(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品出库审核详情(未审核状态)", params, { (rep:DataResponse<OutGoodsDetailModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 商品入库审核详情(未审核状态)

/**
 params-key:
 user_token(验证token)
 
 */
func InGoodsDetail(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("商品入库审核详情(未审核状态)", params, { (rep:DataResponse<InGoodsDetailModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}

//MARK: -- 出库入库审核不通过

/**
 params-key:
 user_token(验证token)
 io_id 出/入库单号
audit_remark 审核备注
 */
func AuditFail(_ params:[String:Any],success:@escaping (_ res:Any)->(),failture:@escaping(_ error:Error)->()) {
    NetworkRequest.sharedInstance.postRequest("出库入库审核不通过", params, { (rep:DataResponse<UpDataModel>) in
    }, success: { (data) in
        success(data)
    }) { (error) in
        failture(error)
    }
}
